@@ -1,11 +1,15 @@
 import asyncio
 from enum import Enum
 from typing import List, Optional
+from io import StringIO
 
 from databases import Database
 import typer
 
 
+app = typer.Typer()
+
+
 class QueryType(str, Enum):
     fetch = "fetch"
     execute = "execute"
@@ -13,7 +17,7 @@ class QueryType(str, Enum):
 
 def query_main(
     host: str,
-    files: Optional[List[typer.FileText]] = typer.Argument(None),
+    files: Optional[List[StringIO]] = None,
     ssl: Optional[bool] = False,
     query_type: QueryType = QueryType.fetch
 ):
@@ -31,9 +35,14 @@ def query_main(
             typer.echo(asyncio.run(database.execute(query)))
 
 
-def main():
-    typer.run(query_main)
-
+@app.command()
+def main(
+    host: str,
+    files: Optional[List[typer.FileText]] = typer.Argument(None),
+    ssl: Optional[bool] = False,
+    query_type: QueryType = QueryType.fetch
+):
+    query_main(host, files, ssl, query_type)
 
 if __name__ == "__main__":
-    main()
+    app()
